@@ -1,4 +1,4 @@
-# $Id: /mirror/gungho/lib/Gungho/Component/RobotRules.pm 2906 2007-09-28T10:37:05.674821Z lestrrat  $
+# $Id: /mirror/gungho/lib/Gungho/Component/RobotRules.pm 3230 2007-10-10T14:02:03.768352Z lestrrat  $
 #
 # Copyright (c) 2007 Daisuke Maki <daisuke@endeworks.jp>
 
@@ -48,7 +48,7 @@ sub allowed
 {
     my ($c, $request) = @_;
 
-    my $rule = $c->robot_rules_storage->get_rule( $request );
+    my $rule = $c->robot_rules_storage->get_rule( $c, $request );
     if (! $rule) {
         if ($c->push_pending_robots_txt($request) == 0) {
             return -2;
@@ -73,9 +73,10 @@ sub handle_response
     my ($request, $response) = @_;
 
     if ($request->uri->path eq '/robots.txt' && $request->notes('auto_robot_rules')) {
+        $c->log->debug("Handling robots.txt response for " . $request->uri->path) if $c->log->is_debug;
         $c->parse_robot_rules($request, $response);
         $c->dispatch_pending_robots_txt($request);
-        Gungho::Exception::HandleResponse::Handle->throw;
+        Gungho::Exception::HandleResponse::Handled->throw;
     }
 
     $c->maybe::next::method(@_);
@@ -93,7 +94,7 @@ sub push_pending_robots_txt
     }
 
     if(! exists $h->{ $request->id }) {
-        $c->log->debug("Pushing request " . $request->id . " to pending list (robot rules)...")
+        $c->log->debug("Pushing request " . $request->uri . " to pending list (robot rules)...")
             if $c->log->is_debug;
         $h->{ $request->id } = $request ;
         return 1;
@@ -122,7 +123,7 @@ sub setup_robot_rules_storage
     my $pkg_config = $config->{config} || {};
     $pkg = $c->load_gungho_module($pkg, 'Component');
     my $storage = $pkg->new(%$config);
-    $storage->setup();
+    $storage->setup($c);
     $c->robot_rules_storage( $storage );
 }
 
@@ -147,8 +148,9 @@ sub parse_robot_rules
         $c->robot_rules_parser->parse($request->original_uri, $response->content) :
         {}
     ;
+    $c->log->debug("Parse robot rules " . $request->uri . ": " . keys(%$h) . " rules") if $c->log->is_debug;
     my $rule = Gungho::Component::RobotRules::Rule->new($h);
-    $c->robot_rules_storage->put_rule($request, $rule);
+    $c->robot_rules_storage->put_rule($c, $request, $rule);
 }
 
 1;
